@@ -8,7 +8,6 @@ from .authentication import get_user_email
 from arcane.pubsub.utils import pubsub_json_message_decoder
 from flask_log_request_id import current_request_id
 
-
 def catch_exceptions_service(service: str, pubsub_subscriber: bool=False, auth_enabled=True) -> Callable:
     """ Catch if an exception is raised after an endpoint call and alert it with arguments or parameters (pubsub case)
         passed to this endpoint
@@ -38,14 +37,13 @@ def catch_exceptions_service(service: str, pubsub_subscriber: bool=False, auth_e
                 except ValueError:
                     pass
                 traceback_str = traceback.format_exc()
-                print(f"{traceback_str}\n{message}")
                 request_id = None
                 import sys
                 try:
                     request_id = current_request_id()
                 except KeyError:
                     pass
-                raise type(e)(f"[{request_id}]: {str(e)}").with_traceback(sys.exc_info()[2])
+                raise Exception(f"[{request_id}]: {str(e)}").with_traceback(sys.exc_info()[2]) from e
         return wrapper
     return catch_exceptions
 
@@ -65,6 +63,6 @@ def add_id_to_exceptions() -> Callable:
                     request_id = current_request_id()
                 except KeyError:
                     pass
-                raise type(e)(f"[{request_id}]: {str(e)}").with_traceback(sys.exc_info()[2])
+                raise Exception(f"[{request_id}]: {str(e)}").with_traceback(sys.exc_info()[2]) from e
         return wrapper
     return catch_exceptions
